/*
 * @guiStartAppPanel.java Version 1.1 02/24/2017
 *
 * Copyright (c) 2017 Kansas Geological Survey
 * 1930 Constant Avenue, Lawrence, Kansas, 66047, U.S.A.
 * All Rights Reserved.
 */

package gui;

import java.awt.*;
import java.awt.image.*;
import java.awt.event.*;
import java.io.File;
import java.io.FileFilter;
import java.io.IOException;
import javax.swing.*;
import javax.swing.event.*;
import javax.swing.border.*;

import util.utilDirectory;

//import co2.gui.co2Frame;          // CO2 Control Data Dialog

/** Class guiStartAppPanel
 *  <p> This Class Starting Panel for this web application
 *
 *  @version 1.1 02/24/2017
 *  @author  John R. Victorine
 */

public class guiStartAppPanel extends JPanel implements ActionListener
{
  // Input Variables

  private JFrame        parent = null;  // Frame calling this panel
  private utilDirectory pUtil  = null;

  // Global Variable

//  private co2Frame frame       = null;

  private String   sReadMethod = null;
  private String   sDirectory  = null;
  private String   sFilename   = null;

  // Global Panel Widgets

  private JButton    btn      = null;
  private JButton    btnExit  = new JButton();

  /** Constructor guiStartAppPanel( JFrame parent )
   *  <p> This is the Constructor for this class.
   *  @param parent   = the frame calling this panel
   */

  public guiStartAppPanel( JFrame parent )
  {
    try
    {
      this.parent   = parent;

      jbInit();
    }
    catch(Exception ex)
    {
      ex.printStackTrace();
    }
  }

  /** METHOD jbInit()
   *  <p> This Method will create the Panel for this class.
   *  @throws Exception
   */

  private void jbInit() throws Exception
  {
    JPanel pnlCenter = new JPanel();
    JPanel pnlBase   = new JPanel();

    JLabel lbl       = new JLabel();

    // Build Panel

    this.setLayout( new BorderLayout() );
    this.setBackground(Color.white);

    pnlCenter.setLayout( new BorderLayout() );
    pnlCenter.setBackground(Color.white);

    btn = new JButton( createImageIcon( "/images/waves.png" ) );
    btn.setBackground(Color.white);
    btn.addActionListener( this );

    lbl.setHorizontalAlignment(SwingConstants.CENTER);
    lbl.setFont(new java.awt.Font("Dialog", 1, 20));
    lbl.setBackground(Color.white);
    lbl.setText("Enter");

    pnlBase.setLayout( new GridLayout() );
    pnlBase.setBackground(Color.white);

    btnExit.setFont(new java.awt.Font("Dialog", 1, 11));
    btnExit.setText("Exit");
    btnExit.addActionListener(this);

    // Add Widgets to Panel

    this.add( pnlCenter,    BorderLayout.CENTER );
    pnlCenter.add( btn,     BorderLayout.CENTER );
    pnlCenter.add( lbl,     BorderLayout.SOUTH );

    if (parent != null)
    {
      this.add( pnlBase,    BorderLayout.SOUTH );
      pnlBase.add( btnExit, null );
    }
  }

  /** METHOD createImageIcon()
   *  <p> This Method will create the Frame for this class.
   *  @param path = the path to the image
   *  @return image icon
   */

  protected ImageIcon createImageIcon(String path)
  {
    java.net.URL imgURL = getClass().getResource(path);
    ImageIcon    image  = null;

    if (imgURL != null)
    {
      image = new ImageIcon(imgURL);
    }
    else
    {
       System.err.println("Couldn't find file: " + path);
    }

    return (image);
  }

  /** Method search()
   * <p> This method will search for a the starting directory path holding all
   *     the sensor ID data for the week on the user's PC
   */

  private void search()
  {
    JFileChooser chooser = new JFileChooser();

    //chooser.setCurrentDirectory(new java.io.File("."));
    chooser.setCurrentDirectory(new java.io.File("user.home"));
    chooser.setDialogTitle("Search for the Seismic Data Directory");
    chooser.setFileSelectionMode(JFileChooser.DIRECTORIES_ONLY);
    chooser.setAcceptAllFileFilterUsed(false);

    if (chooser.showOpenDialog(null) == JFileChooser.APPROVE_OPTION)
    {
	  getTopDirectory( chooser.getSelectedFile().toString(),
                       chooser.getCurrentDirectory().toString() );
    }
    else
    {
      System.out.println("No Selection ");
    }
  }

  /** Method void getTopDirectory()
   *  <p> This method will get the immediate contents of the main directory, i.e, the
   *      top directory holding the sub-directories of the datas of the seismic data.
   *
   *      TOP = C:\Users\jvictor\My Documents\My Files\PROJECT-DOE_CO2_PhaseII\REORDER_SEISMIC_FILES-example\TEST
   *      Selected Directory = original
   *
   *      sDirectory = TOP\original  Original is directory name of interest,
   *                                   all the seismic data exists below
   *      sPath      = TOP           The Top directory path where the re-ordered
   *                                   seismic files will end up
   *
   *  @param sDirectory = directory file path
   *  @param sPath      = directory path to sDirectory
   */

  private void getTopDirectory( String sDirectory, String sPath )
  {
	String sTopDirName = null;
    File   directory   = null;
	File[] subdirs     = null;

    try
    {
      directory   = new File( sDirectory );            // Create File Object of top Directory
	  sTopDirName = new String( directory.getName() ); // Get The top directory name

      //System.out.println("Top Directory Path: " + sTopDirName);
      //System.out.println("SELECTED: "+ sPath);

      subdirs = directory.listFiles();                 // Get Subdirectory Path Names

      for(File dir : subdirs)                          // FOR EACH subdirs in top directory
      {
        copyDirectory( dir.toString(), sPath );        //   Build directory path for seismic data
                                                       //   - Sensor ID/Date/
                                                       //   - Move sensor ID directory under new Directory
                                                       //   - Delete Empty date directory from selected
                                                       //     directory

        //System.out.println("SUB-Dir Path : " + dir.toString());
        //System.out.println("SUB-Directory: " + dir.getName());
	  }                                                // END FOR EACH subdirs in top directory

	  directory.delete();                              // Delete the Selected Directory ( should be empty )
    }
    catch(Exception e)
    {
      // if any error occurs
      e.printStackTrace();
    }
  }


  /** Method void copyDirectory()
   *  <p> This method will
   *      -- Build NEW directory path for seismic data, i.e. TOP/Sensor ID/Date/
   *      -- Move sensor ID directory from Selected directory/Date to the NEW Directory Path, i.e.
   *         MOVE: TOP/Selected Directory/Date/Sensor ID to  TOP/Sensor ID/Date/Sensor ID
   *         MOVE: TOP/original/2016365/9472 to TOP/9472/2016365/9472
   *      -- Delete Empty Date Directory from under the Selected Directory, i.e.
   *         DELETE: TOP/original/2016365
   *
   *      Example:
   *      TOP = C:\Users\jvictor\My Documents\My Files\PROJECT-DOE_CO2_PhaseII\REORDER_SEISMIC_FILES-example\TEST
   *      Selected Directory = original
   *      Date               = 2016365; FORMAT YYYYDay
   *      Sensor ID          = 9472
   *
   *  @param sDirectory = directory file path
   *  @param sPath      = directory path to sDirectory
   */

  private void copyDirectory( String sDirectory, String sPath )
  {
	String sTopDirName = null;
	String sSubDirName = null;
	String sPathOrig   = null;
	String sPathNew    = null;
	String sPathSensor = null;
	String sPathDate   = null;
	String sPathTarget = null;

    File directory = null;
	File[] subdirs = null;

	File source    = null;
	File target    = null;

    pUtil = new utilDirectory();

    try
    {
      directory   = new File( sDirectory );          // Create File Object for Directory

	  sTopDirName = new String(directory.getName()); // Get The Date String

      subdirs     = directory.listFiles();           // Get Subdirectory Path Names

      sPathNew    = new String( sPath );             // Copy the path to a new variable name

      for(File dir : subdirs)                        // FOR EACH Sensor ID in Sensor ID Array
      {
		sSubDirName = new String( dir.getName() );   //   Get Sensor ID

        // Build source Directory, directory path for sensor data at specific date,
        // i.e. TOP\original\2016365\9472

        sPathOrig   = new String( sDirectory + "\\" + sSubDirName );
        source      = new File( sPathOrig );

        // Build new Directory Structure
        // -- Add Sensor ID to TOP directory,
        //    i.e. make a new directory TOP\9472
        // -- MAKE DIRECTORY TOP/Sensor ID, i.e. MKDIR - TOP\9472

        sPathSensor = new String( sPathNew + "\\" + sSubDirName );
        mkdir(sPathSensor);

        // -- Add Date to TOP/Sensor ID directory,
        //    i.e. make a new directory TOP\9472\2016365
        // -- MAKE DIRECTORY TOP/Sensor ID/Date, i.e. MKDIR - TOP\9472\2016365

        sPathDate   = new String( sPathSensor  + "\\" + sTopDirName );
        mkdir(sPathDate);

        // -- Build target Directory, directory path for sensor data directory,
        //    i.e. make a new directory TOP\9472\2016365\9472
        // -- MAKE DIRECTORY TOP/Sensor ID/Date/Sensor ID, i.e. MKDIR - TOP\9472\2016365\9472
        // -- MOVE sensor data from source directory to target directory,
        //    i.e. TOP\original\2016365\9472 to TOP\9472\2016365\9472

        sPathTarget = new String( sPathDate + "\\" + sSubDirName );
        target      = new File( sPathTarget );
        source.renameTo(target);

        // prints file and directory paths

        //System.out.println(dir.getName());
      }                                              // END FOR EACH

      directory.delete();                            // Delete Date Directory,
    }
    catch(Exception e)
    {
      // if any error occurs
      e.printStackTrace();
    }
  }

  /** Method mkdir()
   *  <p> This method will make a directory
   *  @param sFile = new directory string
   */

  public void mkdir( String sFile )
  {
	File pNew = null;
	try
	{
	  pNew = new File(sFile);
	  //System.out.println(pNew.toString());

	  if (!pNew.exists())
	  {
	    pNew.mkdir();
	  }
	}
    catch(Exception e)
    {
      // if any error occurs

      e.printStackTrace();
    }
  }

  /* ===================================================================== *
   * ---------------------------- ACTIONS -------------------------------- *
   * ===================================================================== */

  /** Method close()
   * <p> This method will close all dialogs that are opened by this class.
   */

  public void close()
  {
    // Input Variables

    sReadMethod = null;
    sDirectory  = null;
    sFilename   = null;

    // Global Panel Widgets

    btn      = null;
    btnExit  = null;

    if (parent != null)
    {
      parent.dispose();
      parent = null;

      System.exit(0);
    }
  }

  /** Method callFrame()
   * <p> This method will open the CO2 Frame to get CO2 File
   */

  private void callFrame()
  {
	search();

    if ((sDirectory != null) && (sFilename != null))
      System.out.println( sDirectory );
  }

  /** METHOD actionPerformed()
   *  <p> This Method will handle all the actions within the Frame.
   *  @param event - Action Event
   */

  public void actionPerformed(ActionEvent event)
  {
    if (event.getSource() == btn)     { callFrame(); }
    if (event.getSource() == btnExit) { close(); }
  }
}

/*
 *  @version 1.1 02/24/2017
 *  @author  John Victorine
 */
