/*
 * @utilDirectory.java Version 1.1 03/13/2001
 *
 * Copyright (c) 2001 Kansas Geological Survey
 * 1930 Constant Avenue, Lawrence, Kansas, 66047, U.S.A.
 * All Rights Reserved.
 */

package util;

import java.io.*;
import java.io.File;
import java.io.FileFilter;
import java.io.IOException;
import java.net.*;
import java.lang.*;
import java.text.*;
import java.util.*;
import java.awt.*;
import java.util.zip.*;

/** Class utilDirectory
 *  <p> This Class is designed to open an ascii text file and load
 *      the contents into a string buffer.
 *
 *  @version 1.1 03/13/2001
 *  @author  John R. Victorine
 */

public class utilDirectory
{
  /** Constructor utilDirectory()
   * <p> This is the Constructor for this class.
   */

  public utilDirectory() {  }

  /** copy()
   *  <p> Copy Directory or File from source to target
   *  @param sourceLocation = source location
   *  @param targetLocation = target location
   */

  public void copy(File sourceLocation, File targetLocation) throws IOException
  {
    if (sourceLocation.isDirectory())
    {
      copyDirectory(sourceLocation, targetLocation);
    }
    else
    {
//      copyFile(sourceLocation, targetLocation);
      moveFile(sourceLocation, targetLocation);
    }
  }

  /** copyDirectory()
   *  <p> Copy Directory and contents from one directory structure to another.
   *  @param source = source Directory File path
   *  @param target = target Directory File path
   */

  public void copyDirectory(File source, File target) throws IOException
  {
    if (!target.exists())
    {
      target.mkdir();
    }

    for (String f : source.list())
    {
      copy(new File(source, f), new File(target, f));
    }
  }

  /** copyFile()
   *  <p> Copy File from source to target
   *  @param source = file source
   *  @param target = file target
   */

  public void copyFile(File source, File target) throws IOException
  {
    try
    (
	  InputStream  in  = new FileInputStream(source);
      OutputStream out = new FileOutputStream(target)
    )
    {
      byte[] buf = new byte[1024];
      int length = 0;

      while ((length = in.read(buf)) > 0)
      {
        out.write(buf, 0, length);
      }
    }
  }

  public void moveFile(File source, File target) throws IOException
  {
    try
    {
	  if (source.renameTo(target))
	  {
		System.out.println(source.getName()+" File is moved successful!");
	  }
	  else
	  {
		System.out.println(source.getName()+" File is failed to move!");
	  }
	}
    catch(Exception e)
    {
	  e.printStackTrace();
    }

  }
}